@@ -3,39 +3,41 @@ setClassUnion("matrixOrVector", c("matrix","numeric"))
 
 # Class to store actual parameter estimates
 setClass("unmarkedEstimate",
-    representation(name = "character",
-				short.name = "character",
+    representation(
+        name = "character",
+		short.name = "character",
         estimates = "numeric",
         covMat = "matrix",
-                   covMatBS = "optionalMatrix",
+        covMatBS = "optionalMatrix",
         invlink = "character",
         invlinkGrad = "character"),
     validity = function(object) {
-      errors <- character(0)
-      if(nrow(object@covMat) != length(object@estimates)) {
-        errors <- c(errors, "Size of covMat does not match length of estimates.")
-      }
-      if(length(errors) > 0)
+        errors <- character(0)
+        if(nrow(object@covMat) != length(object@estimates)) {
+        errors <- c(errors, 
+            "Size of covMat does not match length of estimates.")
+        }
+    if(length(errors) > 0)
         errors
-      else
+    else
         TRUE
     })
 
 setClass("unmarkedEstimateList",
     representation(estimates = "list"),
     validity = function(object) {
-      errors <- character(0)
-      for(est in object@estimates) {
-        if(!is(est, "unmarkedEstimate")) {
-          errors <- c("At least one element of unmarkedEstimateList is not an unmarkedEstimate.")
-          break
-        }
-      }
-      if(length(errors) == 0) {
-        return(TRUE)
-      } else {
-        return(errors)
-      }
+        errors <- character(0)
+        for(est in object@estimates) {
+            if(!is(est, "unmarkedEstimate")) {
+                errors <- c("At least one element of unmarkedEstimateList is not an unmarkedEstimate.")
+                break
+                }
+            }
+        if(length(errors) == 0) {
+            return(TRUE)
+        } else {
+            return(errors)
+            }
     })
 
 setMethod("show", "unmarkedEstimateList",
@@ -47,12 +49,16 @@ setMethod("show", "unmarkedEstimateList",
     })
 
 setMethod("summary", "unmarkedEstimateList",
-    function(object) {
-      for(est in object@estimates) {
-        summary(est)
+    function(object) 
+{
+    sumList <- list()
+    for(i in 1:length(object@estimates)) {
+        sumList[[i]] <- summary(object@estimates[[i]])
         cat("\n")
-      }
-    })
+        }
+    names(sumList) <- names(object@estimates)
+    invisible(sumList)
+})
 
 setGeneric("estimates",
     function(object) {
@@ -75,37 +81,35 @@ unmarkedEstimateList <- function(l) {
 
 
 
-unmarkedEstimate <- function(name, short.name, estimates, covMat, invlink, invlinkGrad) {
-
-  new("unmarkedEstimate",
-      name = name,
-			short.name = short.name,
-      estimates = estimates,
-      covMat = covMat,
-      invlink = invlink,
-      invlinkGrad = invlinkGrad)
-
+unmarkedEstimate <- function(name, short.name, estimates, covMat, invlink, 
+    invlinkGrad) 
+{
+    new("unmarkedEstimate", 
+        name = name, 
+        short.name = short.name,
+        estimates = estimates,
+        covMat = covMat,
+        invlink = invlink,
+        invlinkGrad = invlinkGrad)
 }
 
-setMethod("show",
-    signature(object = "unmarkedEstimate"),
-    function(object) {
-      ests <- object@estimates
-      SEs <- SE(object)
-      Z <- ests/SEs
-			p <- 2*pnorm(abs(Z), lower.tail = FALSE)
-			printRowNames <- 
-					!(length(ests) == 1 | identical(names(ests), "(Intercept)") | identical(names(ests), "1"))
+
+setMethod("show", signature(object = "unmarkedEstimate"),
+    function(object) 
+{
+    ests <- object@estimates
+    SEs <- SE(object)
+    Z <- ests/SEs
+	p <- 2*pnorm(abs(Z), lower.tail = FALSE)
+	printRowNames <- !(length(ests) == 1 | 
+        identical(names(ests), "(Intercept)") | identical(names(ests), "1"))
 			
-			cat(object@name,":\n", sep="")
-			outDF <- data.frame(Estimate = ests,
-					SE = SEs,
-					z = Z,
-          "P(>|z|)" = p,
+	cat(object@name,":\n", sep="")
+	outDF <- data.frame(Estimate = ests, SE = SEs, z = Z, "P(>|z|)" = p,
           check.names = FALSE)
-      print(outDF, row.names = printRowNames, digits = 3)
+    print(outDF, row.names = printRowNames, digits = 3)
 			
-    })
+})
 
 
 
@@ -126,6 +130,7 @@ setMethod("summary", signature(object = "unmarkedEstimate"),
 	outDF <- data.frame(Estimate = ests, SE = SEs, z = Z, "P(>|z|)" = p,
 		check.names = FALSE)
 	print(outDF, row.names = printRowNames, digits = 3)
+	invisible(outDF)
 })
 	
 
@@ -133,24 +138,26 @@ setMethod("summary", signature(object = "unmarkedEstimate"),
 # Compute linear combinations of estimates in unmarkedEstimate objects.
 
 setMethod("linearComb",
-		signature(obj = "unmarkedEstimate", coefficients = "matrixOrVector"),
-		function(obj, coefficients, offset = NULL) {
-			if(!is(coefficients, "matrix")) coefficients <- t(as.matrix(coefficients))
-			stopifnot(ncol(coefficients) == length(obj@estimates))
-                        if (is.null(offset)) offset <- rep(0, nrow(coefficients))
-			e <- as.vector(coefficients %*% obj@estimates) + offset
-			v <- coefficients %*% obj@covMat %*% t(coefficients)
-                        if (!is.null(obj@covMatBS)) {
-                          v.bs <- coefficients %*% obj@covMatBS %*% t(coefficients)
-                        } else {
-                          v.bs <- NULL
-                        }
-			umelc <- new("unmarkedLinComb",
-					parentEstimate = obj,
-					estimate = e, covMat = v, covMatBS = v.bs,
-					coefficients = coefficients)
-			umelc
-		})
+	signature(obj = "unmarkedEstimate", coefficients = "matrixOrVector"),
+	function(obj, coefficients, offset = NULL) 
+{
+	if(!is(coefficients, "matrix")) 
+        coefficients <- t(as.matrix(coefficients))
+	stopifnot(ncol(coefficients) == length(obj@estimates))
+    if (is.null(offset)) 
+        offset <- rep(0, nrow(coefficients))
+	e <- as.vector(coefficients %*% obj@estimates) + offset
+	v <- coefficients %*% obj@covMat %*% t(coefficients)
+    if (!is.null(obj@covMatBS)) {
+        v.bs <- coefficients %*% obj@covMatBS %*% t(coefficients)
+    } else {
+        v.bs <- NULL
+        }
+	umelc <- new("unmarkedLinComb", parentEstimate = obj,
+		estimate = e, covMat = v, covMatBS = v.bs,
+		coefficients = coefficients)
+	umelc
+})
 
 
 # Transform an unmarkedEstimate object to it's natural scale.
@@ -184,14 +191,15 @@ setMethod("linearComb",
 # can backtranform a fit directly if it has length 1
 # o.w. give error
 setMethod("backTransform", "unmarkedEstimate",
-		function(obj) {
-			if(length(obj@estimates) == 1) {
-				lc <- linearComb(obj, 1)
-				return(backTransform(lc))
-			} else {
-				stop("Cannot directly back-transform an unmarkedEstimate with length > 1.\nUse linearComb() and then backTransform() the resulting scalar linear combination.")
-			}
-		})
+	function(obj) 
+{
+	if(length(obj@estimates) == 1) {
+	   lc <- linearComb(obj, 1)
+	   return(backTransform(lc))
+	} else {
+		stop("Cannot directly back-transform an unmarkedEstimate with length > 1.\nUse linearComb() and then backTransform() the resulting scalar linear combination.")
+		}
+})
 
 # Compute standard error of an unmarkedEstimate object.
 
@@ -214,14 +222,15 @@ setMethod("names", "unmarkedEstimateList",
     })
 
 setMethod("coef", "unmarkedEstimate",
-		function(object, altNames = TRUE, ...) {
-			coefs <- object@estimates
-			names(coefs)[names(coefs) == "(Intercept)"] <- "Int"
-			if(altNames) {
-				names(coefs) <- paste(object@short.name, "(", names(coefs), ")", sep="")
-			}
-			coefs
-		})
+	function(object, altNames = TRUE, ...) 
+{
+	coefs <- object@estimates
+	names(coefs)[names(coefs) == "(Intercept)"] <- "Int"
+	if(altNames) {
+		names(coefs) <- paste(object@short.name, "(", names(coefs), ")", sep="")
+		}
+	coefs
+})
 
 setMethod("vcov", "unmarkedEstimate",
 		function(object,...) {
