@@ -1,16 +1,14 @@
 
-############# VALIDATION FUNCTIONS #############################################
+############# VALIDATION FUNCTIONS #######################################
 
-validunmarkedFrame <- function(object) 
+validunmarkedFrame <- function(object)
 {
     errors <- character(0)
     M <- nrow(object@y)
     J <- ncol(object@y)
-    if(J < 2) # matrices can have 0 columns
-        errors <- c(errors, "y must have at least 2 columns")    
     if(!is.null(object@siteCovs))
         if(nrow(object@siteCovs) != M)
-            errors <- c(errors, 
+            errors <- c(errors,
                 "siteCovData does not have same size number of sites as y.")
     if(!is.null(obsCovs(object)) & !is.null(obsNum(object)))
         if(nrow(object@obsCovs) != M*obsNum(object))
@@ -21,7 +19,7 @@ validunmarkedFrame <- function(object)
         errors
 }
 
-############ DATA CLASSES ######################################################
+############ DATA CLASSES ################################################
 
 # Class to hold data for analyses in unmarked.
 setClass("unmarkedFrame",
@@ -36,13 +34,13 @@ setClass("unmarkedFrame",
 
 setClass("unmarkedMultFrame",
     representation(numPrimary = "numeric",
-        #data frame in site-major, year-minor order describing site-level covs
+        #data frame in site-major, year-minor order describing siteCovs
         yearlySiteCovs = "optionalDataFrame"),
     contains="unmarkedFrame")
 
 
 ## a class for distance sampling data
-setClass("unmarkedFrameDS", 
+setClass("unmarkedFrameDS",
     representation(
         dist.breaks = "numeric",
         tlength = "numeric",
@@ -59,7 +57,7 @@ setClass("unmarkedFrameDS",
             errors <- c(errors, "dist.breaks[1] must equal 0")
         if(!is.null(obsCovs(object)))
             "obsCovs cannot be used with distsamp"
-        if(length(errors) == 0) TRUE	
+        if(length(errors) == 0) TRUE
         else errors
         })
 
@@ -78,25 +76,41 @@ setClass("unmarkedFrameMPois",
 			piFun = "character"),
 		contains = "unmarkedFrame")
 
+
+setClass("unmarkedFrameG3",
+    representation(
+        primaryPeriod = "matrix"),
+    contains = "unmarkedMultFrame")
+
+
 setClass("unmarkedFramePCO",
     representation(
         primaryPeriod = "matrix"),
     contains = "unmarkedMultFrame")
 
 
-setClass("unmarkedFrameGMM", 
+setClass("unmarkedFrameGMM",
     representation(
         piFun = "character",
         samplingMethod = "character"),
-    contains = "unmarkedMultFrame")    
+    contains = "unmarkedFrameG3")
+
+setClass("unmarkedFrameGDS",
+    representation(
+        dist.breaks = "numeric",
+        tlength = "numeric",
+        survey = "character",
+        unitsIn = "character"),
+    contains = "unmarkedFrameG3")
 
 
 
-# ------------------------------- CONSTRUCTORS --------------------------------
+# ------------------------------- CONSTRUCTORS ---------------------------
 
 
 # Constructor for unmarkedFrames.
-unmarkedFrame <- function(y, siteCovs = NULL, obsCovs = NULL, mapInfo, obsToY) 
+unmarkedFrame <- function(y, siteCovs = NULL, obsCovs = NULL, mapInfo,
+                          obsToY)
 {
     if(!missing(obsToY))
         obsNum <- nrow(obsToY)
@@ -110,65 +124,65 @@ unmarkedFrame <- function(y, siteCovs = NULL, obsCovs = NULL, mapInfo, obsToY)
             }
         if(is.null(obsNum)) obsNum <- ncol(obsCovs[[1]]) #??
         obsCovs <- data.frame(lapply(obsCovs, function(x) as.vector(t(x))))
-        }    
-    if(("data.frame" %in% class(y)) | ("cast_matrix" %in% class(y))) 
-        y <- as.matrix(y)    
+        }
+    if(("data.frame" %in% class(y)) | ("cast_matrix" %in% class(y)))
+        y <- as.matrix(y)
     if(missing(obsToY)) obsToY <- NULL
     if(missing(mapInfo)) mapInfo <- NULL
-	   
-    umf <- new("unmarkedFrame", y = y, obsCovs = obsCovs, siteCovs = siteCovs, 
+
+    umf <- new("unmarkedFrame", y = y, obsCovs = obsCovs, siteCovs = siteCovs,
         mapInfo = mapInfo, obsToY = obsToY)
     return(umf)
 }
 
 
-unmarkedFrameDS <- function(y, siteCovs = NULL, dist.breaks, tlength, survey,
-		unitsIn, mapInfo = NULL)
+unmarkedFrameDS <- function(y, siteCovs = NULL, dist.breaks, tlength,
+                            survey, unitsIn, mapInfo = NULL)
 {
 	if(missing(survey))
         stop("survey argument must be specified")
-  if(missing(tlength) & survey == "point")
-  tlength <- numeric(0)
+        if(missing(tlength) & survey == "point")
+            tlength <- numeric(0)
 	umfds <- new("unmarkedFrameDS", y = y, obsCovs = NULL,
-			siteCovs = siteCovs, dist.breaks = dist.breaks, tlength = tlength,
-			survey = survey, unitsIn = unitsIn,
-			obsToY = matrix(1, 1, ncol(y)))
+                     siteCovs = siteCovs, dist.breaks = dist.breaks,
+                     tlength = tlength, survey = survey, unitsIn = unitsIn,
+                     obsToY = matrix(1, 1, ncol(y)))
 	return(umfds)
 }
 
 
 
-unmarkedFrameOccu <- function(y, siteCovs = NULL, obsCovs = NULL, mapInfo) 
+unmarkedFrameOccu <- function(y, siteCovs = NULL, obsCovs = NULL, mapInfo)
 {
 	J <- ncol(y)
-	umf <- unmarkedFrame(y, siteCovs, obsCovs, obsToY = diag(J), 
-		mapInfo = mapInfo)
+	umf <- unmarkedFrame(y, siteCovs, obsCovs, obsToY = diag(J),
+                             mapInfo = mapInfo)
 	umf <- as(umf, "unmarkedFrameOccu")
 	umf
 }
 
 
 # This function constructs an unmarkedMultFrame object.
-unmarkedMultFrame <- function(y, siteCovs = NULL, obsCovs = NULL, numPrimary,
-	yearlySiteCovs = NULL) 
+unmarkedMultFrame <- function(y, siteCovs = NULL, obsCovs = NULL,
+                              numPrimary, yearlySiteCovs = NULL)
 {
     J <- ncol(y)
 	  umf <- unmarkedFrame(y, siteCovs, obsCovs, obsToY = diag(J))
     umf <- as(umf, "unmarkedMultFrame")
     umf@numPrimary <- numPrimary
-	
+
     if(class(yearlySiteCovs) == "list") {
         yearlySiteVars <- names(yearlySiteCovs)
         for(i in seq(length(yearlySiteVars))) {
             if(!(class(yearlySiteCovs[[i]]) %in% c("matrix", "data.frame")))
                 stop("At least one element of yearlySiteCovs is not a matrix or data frame.")
-            if(ncol(yearlySiteCovs[[i]]) != numPrimary | 
+            if(ncol(yearlySiteCovs[[i]]) != numPrimary |
                 nrow(yearlySiteCovs[[i]]) != nrow(y))
                     stop("At least one matrix in yearlySiteCovs has incorrect number of dimensions.")
             }
-        yearlySiteCovs <- data.frame(lapply(yearlySiteCovs, function(x) 
+        yearlySiteCovs <- data.frame(lapply(yearlySiteCovs, function(x)
             as.vector(t(x))))
-        }    
+        }
 
     umf@yearlySiteCovs <- yearlySiteCovs
     umf
@@ -177,7 +191,7 @@ unmarkedMultFrame <- function(y, siteCovs = NULL, obsCovs = NULL, numPrimary,
 
 # This function constructs an unmarkedMultFrame object.
 unmarkedFrameGMM <- function(y, siteCovs = NULL, obsCovs = NULL, numPrimary,
-	yearlySiteCovs = NULL, type, obsToY, piFun) 
+	yearlySiteCovs = NULL, type, obsToY, piFun)
 {
     J <- ncol(y) / numPrimary
     if(!missing(type)) {
@@ -192,31 +206,31 @@ unmarkedFrameGMM <- function(y, siteCovs = NULL, obsCovs = NULL, numPrimary,
           },
         double = {
           obsToY <- matrix(1, 2, 3)
-          obsToY <- kronecker(diag(numPrimary), obsToY) 
+          obsToY <- kronecker(diag(numPrimary), obsToY)
           piFun <- "doublePiFun"
           })
     } else {
-        type <- "userDefined" 
-        if(missing(obsToY)) 
+        type <- "userDefined"
+        if(missing(obsToY))
             stop("obsToY is required for gmultmix data with no specified type.")
-        } 
-       
+        }
+
     umf <- unmarkedFrame(y, siteCovs, obsCovs, obsToY = obsToY)
     umf <- as(umf, "unmarkedMultFrame")
     umf@numPrimary <- numPrimary
     if(class(yearlySiteCovs) == "list") {
         yearlySiteVars <- names(yearlySiteCovs)
         for(i in seq(length(yearlySiteVars))) {
-            if(!(class(yearlySiteCovs[[i]]) %in% c("matrix", "data.frame")))
+            if(!(class(yearlySiteCovs[[i]]) %in% c("matrix","data.frame")))
                 stop("At least one element of yearlySiteCovs is not a matrix or data frame.")
-            if(ncol(yearlySiteCovs[[i]]) != numPrimary | 
+            if(ncol(yearlySiteCovs[[i]]) != numPrimary |
                 nrow(yearlySiteCovs[[i]]) != nrow(y))
                     stop("At least one matrix in yearlySiteCovs has incorrect number of dimensions.")
             }
         if(is.null(obsNum)) obsNum <- ncol(obsCovs[[1]])
-        yearlySiteCovs <- data.frame(lapply(yearlySiteCovs, function(x) 
+        yearlySiteCovs <- data.frame(lapply(yearlySiteCovs, function(x)
             as.vector(t(x))))
-        }    
+        }
     umf@yearlySiteCovs <- yearlySiteCovs
     umf <- as(umf, "unmarkedFrameGMM")
     umf@piFun <- piFun
@@ -226,10 +240,54 @@ unmarkedFrameGMM <- function(y, siteCovs = NULL, obsCovs = NULL, numPrimary,
 
 
 
-unmarkedFramePCount <- function(y, siteCovs = NULL, obsCovs = NULL, mapInfo) 
+# This function constructs an unmarkedMultFrame object.
+unmarkedFrameGDS <- function(y, siteCovs, numPrimary,
+	yearlySiteCovs, dist.breaks, survey, unitsIn, tlength)
+{
+    J <- ncol(y) / numPrimary
+    obsToY <- matrix(1, 1, J)
+    obsToY <- kronecker(diag(numPrimary), obsToY)
+    if(missing(siteCovs))
+        siteCovs <- NULL
+
+    umf <- unmarkedFrame(y = y, siteCovs = siteCovs, obsToY = obsToY)
+    umf <- as(umf, "unmarkedMultFrame")
+    umf@numPrimary <- numPrimary
+    if(missing(yearlySiteCovs))
+        yearlySiteCovs <- NULL
+    if(class(yearlySiteCovs) == "list") {
+        yearlySiteVars <- names(yearlySiteCovs)
+        for(i in seq(length(yearlySiteVars))) {
+            if(!(class(yearlySiteCovs[[i]]) %in% c("matrix","data.frame")))
+                stop("At least one element of yearlySiteCovs is not a matrix or data frame.")
+            if(ncol(yearlySiteCovs[[i]]) != numPrimary |
+                nrow(yearlySiteCovs[[i]]) != nrow(y))
+                    stop("At least one matrix in yearlySiteCovs has incorrect number of dimensions.")
+            }
+        yearlySiteCovs <- data.frame(lapply(yearlySiteCovs, function(x)
+            as.vector(t(x))))
+        }
+    if(identical(survey, "point")) {
+        if(!missing(tlength))
+            stop("tlength cannot be specified with point transect data")
+        tlength <- rep(1, nrow(y))
+        }
+
+    umf@yearlySiteCovs <- yearlySiteCovs
+    umf <- as(umf, "unmarkedFrameGDS")
+    umf@dist.breaks <- dist.breaks
+    umf@survey <- survey
+    umf@unitsIn <- unitsIn
+    umf@tlength <- tlength
+    umf
+}
+
+
+
+unmarkedFramePCount <- function(y, siteCovs = NULL, obsCovs = NULL, mapInfo)
 {
     J <- ncol(y)
-    umf <- unmarkedFrame(y, siteCovs, obsCovs, obsToY = diag(J), 
+    umf <- unmarkedFrame(y, siteCovs, obsCovs, obsToY = diag(J),
         mapInfo = mapInfo)
     umf <- as(umf, "unmarkedFramePCount")
     umf
@@ -237,8 +295,8 @@ unmarkedFramePCount <- function(y, siteCovs = NULL, obsCovs = NULL, mapInfo)
 
 
 
-unmarkedFrameMPois <- function(y, siteCovs = NULL, obsCovs = NULL, type, 
-    obsToY, mapInfo, piFun) 
+unmarkedFrameMPois <- function(y, siteCovs = NULL, obsCovs = NULL, type,
+    obsToY, mapInfo, piFun)
 {
     if(!missing(type)) {
         switch(type,
@@ -255,11 +313,11 @@ unmarkedFrameMPois <- function(y, siteCovs = NULL, obsCovs = NULL, type,
                 piFun <- "doublePiFun"
                 })
     } else {
-        if(missing(obsToY)) 
+        if(missing(obsToY))
             stop("obsToY is required for multinomial-Poisson data with no specified type.")
         type <- "userDefined"
         }
-    umf <- unmarkedFrame(y, siteCovs, obsCovs, obsToY = obsToY, 
+    umf <- unmarkedFrame(y, siteCovs, obsCovs, obsToY = obsToY,
         mapInfo = mapInfo)
     umf <- as(umf, "unmarkedFrameMPois")
     umf@piFun <- piFun
@@ -269,8 +327,8 @@ unmarkedFrameMPois <- function(y, siteCovs = NULL, obsCovs = NULL, type,
 
 
 
-unmarkedFramePCO <- function(y, siteCovs = NULL, obsCovs = NULL, 
-    yearlySiteCovs = NULL, mapInfo, numPrimary, primaryPeriod) 
+unmarkedFramePCO <- function(y, siteCovs = NULL, obsCovs = NULL,
+    yearlySiteCovs = NULL, mapInfo, numPrimary, primaryPeriod)
 {
     M <- nrow(y)
     T <- numPrimary
@@ -283,7 +341,7 @@ unmarkedFramePCO <- function(y, siteCovs = NULL, obsCovs = NULL,
         stop("Negative primaryPeriod values are not allowed.")
     if(!identical(typeof(primaryPeriod), "integer")) {
         mode(primaryPeriod) <- "integer"
-        warning("primaryPeriod values have been converted to integers")      
+        warning("primaryPeriod values have been converted to integers")
         }
     ya <- array(y, c(M, J, T))
     yt.na <- apply(!is.na(ya), c(1,3), any)
@@ -309,17 +367,17 @@ unmarkedFramePCO <- function(y, siteCovs = NULL, obsCovs = NULL,
         }
     umf <- unmarkedFrame(y, siteCovs, obsCovs, obsToY = diag(J*T))
     umf <- as(umf, "unmarkedMultFrame")
-    umf@numPrimary <- numPrimary    
+    umf@numPrimary <- numPrimary
     if(class(yearlySiteCovs) == "list") {
         yearlySiteVars <- names(yearlySiteCovs)
         for(i in seq(length(yearlySiteVars))) {
-            if(!(class(yearlySiteCovs[[i]]) %in% c("matrix", "data.frame")))
+            if(!(class(yearlySiteCovs[[i]]) %in% c("matrix","data.frame")))
                 stop("At least one element of yearlySiteCovs is not a matrix or data frame.")
-            if(ncol(yearlySiteCovs[[i]]) != T | 
+            if(ncol(yearlySiteCovs[[i]]) != T |
                 nrow(yearlySiteCovs[[i]]) != nrow(y))
                     stop("At least one matrix in yearlySiteCovs has incorrect number of dimensions.")
             }
-        yearlySiteCovs <- data.frame(lapply(yearlySiteCovs, function(x) 
+        yearlySiteCovs <- data.frame(lapply(yearlySiteCovs, function(x)
             as.vector(t(x))))
         }
     umf@yearlySiteCovs <- yearlySiteCovs
@@ -333,10 +391,10 @@ unmarkedFramePCO <- function(y, siteCovs = NULL, obsCovs = NULL,
 
 
 
-################ SHOW METHODS ##################################################
+################ SHOW METHODS ############################################
 
 
-setMethod("show", "unmarkedFrame", function(object) 
+setMethod("show", "unmarkedFrame", function(object)
 {
     df <- as(object, "data.frame")
     cat("Data frame representation of unmarkedFrame object.\n")
@@ -345,11 +403,11 @@ setMethod("show", "unmarkedFrame", function(object)
 
 
 setMethod("show", "unmarkedMultFrame",
-    function(object) 
+    function(object)
 {
     df <- as(object, "data.frame")
     ysc <- yearlySiteCovs(object)
-    if(is.null(ysc)) { 
+    if(is.null(ysc)) {
         cat("Data frame representation of unmarkedFrame object.\n")
         print(df)
         }
@@ -363,38 +421,36 @@ setMethod("show", "unmarkedMultFrame",
 })
 
 
-############################ EXTRACTORS ########################################
+############################ EXTRACTORS ##################################
 
 # Extractor for site level covariates
 setGeneric("siteCovs", function(object,...) standardGeneric("siteCovs"))
-setMethod("siteCovs", "unmarkedFrame",
-		function(object) {
-			return(object@siteCovs)
-		})
 
-setGeneric("yearlySiteCovs", 
-	function(object,...) standardGeneric("yearlySiteCovs"))
-setMethod("yearlySiteCovs", "unmarkedMultFrame",
-		function(object) {
-			return(object@yearlySiteCovs)
-		})
+setMethod("siteCovs", "unmarkedFrame", function(object) {
+    return(object@siteCovs)
+})
+
+setGeneric("yearlySiteCovs", function(object,...)
+    standardGeneric("yearlySiteCovs"))
+setMethod("yearlySiteCovs", "unmarkedMultFrame", function(object) {
+    return(object@yearlySiteCovs)
+})
 
 setGeneric("obsCovs", function(object,...) standardGeneric("obsCovs"))
-setMethod("obsCovs", "unmarkedFrame", 
-		function(object, matrices = FALSE) {
-			M <- numSites(object)
-			R <- obsNum(object)
-			if(matrices) {
-				value <- list()
-				for(i in seq(length=length(object@obsCovs))){
-					value[[i]] <- matrix(object@obsCovs[,i], M, R, byrow = TRUE)
-				}
-				names(value) <- names(object@obsCovs)
-			} else {
-				value <- object@obsCovs
-			}
-			return(value)
-		})
+setMethod("obsCovs", "unmarkedFrame", function(object, matrices = FALSE) {
+    M <- numSites(object)
+    R <- obsNum(object)
+    if(matrices) {
+        value <- list()
+        for(i in seq(length=length(object@obsCovs))){
+            value[[i]] <- matrix(object@obsCovs[,i], M, R, byrow = TRUE)
+        }
+        names(value) <- names(object@obsCovs)
+    } else {
+        value <- object@obsCovs
+    }
+    return(value)
+})
 
 
 setGeneric("obsNum", function(object) standardGeneric("obsNum"))
@@ -413,35 +469,38 @@ setGeneric("obsToY", function(object) standardGeneric("obsToY"))
 setMethod("obsToY", "unmarkedFrame", function(object) object@obsToY)
 
 
-setGeneric("obsCovs<-", function(object, value) standardGeneric("obsCovs<-"))
+setGeneric("obsCovs<-", function(object, value)
+    standardGeneric("obsCovs<-"))
 setReplaceMethod("obsCovs", "unmarkedFrame", function(object, value) {
-			if(identical(class(object)[1], "unmarkedFrameDS"))
-			     stop("unmarkedFrameDS objects cannot have obsCovs")     
-            object@obsCovs <- as.data.frame(value)
-			object
-		})
+    if(identical(class(object)[1], "unmarkedFrameDS"))
+        stop("unmarkedFrameDS objects cannot have obsCovs")
+    object@obsCovs <- as.data.frame(value)
+    object
+})
 
 
-setGeneric("siteCovs<-", function(object, value) standardGeneric("siteCovs<-"))
+setGeneric("siteCovs<-", function(object, value)
+    standardGeneric("siteCovs<-"))
 setReplaceMethod("siteCovs", "unmarkedFrame", function(object, value) {
-			object@siteCovs <- as.data.frame(value)
-			object
-		})
+    object@siteCovs <- as.data.frame(value)
+    object
+})
 
 
-setGeneric("yearlySiteCovs<-", 
+setGeneric("yearlySiteCovs<-",
 	function(object, value) standardGeneric("yearlySiteCovs<-"))
-setReplaceMethod("yearlySiteCovs", "unmarkedMultFrame", function(object, value) {
-			object@yearlySiteCovs <- as.data.frame(value)
-			object
-		})
+setReplaceMethod("yearlySiteCovs", "unmarkedMultFrame",
+    function(object, value) {
+        object@yearlySiteCovs <- as.data.frame(value)
+        object
+    })
 
 
 setGeneric("obsToY<-", function(object, value) standardGeneric("obsToY<-"))
 setReplaceMethod("obsToY", "unmarkedFrame", function(object, value) {
-			object@obsToY <- value
-			object
-		})
+    object@obsToY <- value
+    object
+})
 
 
 
@@ -450,109 +509,104 @@ setMethod("getY", "unmarkedFrame", function(object) object@y)
 
 
 setGeneric("coordinates", function(object) standardGeneric("coordinates"))
-setMethod("coordinates", "unmarkedFrame",
-		function(object) {
-			object@mapInfo@coordinates
-		})
+setMethod("coordinates", "unmarkedFrame", function(object) {
+    object@mapInfo@coordinates
+})
 
 
 setGeneric("projection", function(object) standardGeneric("projection"))
-setMethod("projection", "unmarkedFrame",
-		function(object) {
-			object@mapInfo@projection
-		})
+setMethod("projection", "unmarkedFrame", function(object) {
+    object@mapInfo@projection
+})
 
-################################### SUMMARY METHODS ############################
+################################### SUMMARY METHODS ######################
 
 
-setMethod("summary", "unmarkedFrame",
-	function(object,...) {
-		cat("unmarkedFrame Object\n\n")
-		cat(nrow(object@y), "sites\n")
-		cat("Maximum number of observations per site:",obsNum(object),"\n")
-			mean.obs <- mean(rowSums(!is.na(getY(object))))
-		cat("Mean number of observations per site:",round(mean.obs,2),"\n")
-		cat("Sites with at least one detection:", 
-			sum(apply(getY(object), 1, function(x) any(x > 0, na.rm=TRUE))), 
-				"\n\n")
-		cat("Tabulation of y observations:")
-		print(table(object@y, exclude=NULL))
-		if(!is.null(object@siteCovs)) {
-			cat("\nSite-level covariates:\n")
-			print(summary(object@siteCovs))
-			}
-		if(!is.null(object@obsCovs)) {
-			cat("\nObservation-level covariates:\n")
-			print(summary(object@obsCovs))
-			}
-	})
+setMethod("summary", "unmarkedFrame", function(object,...) {
+    cat("unmarkedFrame Object\n\n")
+    cat(nrow(object@y), "sites\n")
+    cat("Maximum number of observations per site:",obsNum(object),"\n")
+    mean.obs <- mean(rowSums(!is.na(getY(object))))
+    cat("Mean number of observations per site:",round(mean.obs,2),"\n")
+    cat("Sites with at least one detection:",
+        sum(apply(getY(object), 1, function(x) any(x > 0, na.rm=TRUE))),
+        "\n\n")
+    cat("Tabulation of y observations:")
+    print(table(object@y, exclude=NULL))
+    if(!is.null(object@siteCovs)) {
+        cat("\nSite-level covariates:\n")
+        print(summary(object@siteCovs))
+    }
+    if(!is.null(object@obsCovs)) {
+        cat("\nObservation-level covariates:\n")
+        print(summary(object@obsCovs))
+    }
+})
 
-	
 
-setMethod("summary", "unmarkedFrameDS", 
-	function(object, ...) 
+
+setMethod("summary", "unmarkedFrameDS", function(object, ...)
 {
-	cat("unmarkedFrameDS Object\n\n")
-	cat(object@survey, "-transect survey design", "\n", sep="")
-	cat(paste("Distance class cutpoints (", object@unitsIn, "): ", sep=""), 
-		object@dist.breaks, "\n\n")
-	cat(nrow(object@y), "sites\n")
-	cat("Maximum number of distance classes per site:", ncol(getY(object)), "\n")
-		mean.dc <- mean(rowSums(!is.na(getY(object))))
-	cat("Mean number of distance classes per site:", round(mean.dc, 2), "\n")
-	cat("Sites with at least one detection:", 
-		sum(apply(getY(object), 1, function(x) any(x > 0, na.rm=TRUE))), "\n\n")
-	cat("Tabulation of y observations:")
-	print(table(object@y, exclude=NULL))
-	if(!is.null(object@siteCovs)) {
-		cat("\nSite-level covariates:\n")
-		print(summary(object@siteCovs))
-		}
-	if(!is.null(object@obsCovs)) {
-		warning("Observation-level covariates cannot be used by distsamp()")
-		}
+    cat("unmarkedFrameDS Object\n\n")
+    cat(object@survey, "-transect survey design", "\n", sep="")
+    cat(paste("Distance class cutpoints (", object@unitsIn, "): ", sep=""),
+        object@dist.breaks, "\n\n")
+    cat(nrow(object@y), "sites\n")
+    cat("Maximum number of distance classes per site:", ncol(getY(object)), "\n")
+    mean.dc <- mean(rowSums(!is.na(getY(object))))
+    cat("Mean number of distance classes per site:", round(mean.dc, 2), "\n")
+    cat("Sites with at least one detection:",
+        sum(apply(getY(object), 1, function(x) any(x > 0, na.rm=TRUE))), "\n\n")
+    cat("Tabulation of y observations:")
+    print(table(object@y, exclude=NULL))
+    if(!is.null(object@siteCovs)) {
+        cat("\nSite-level covariates:\n")
+        print(summary(object@siteCovs))
+    }
+    if(!is.null(object@obsCovs)) {
+        warning("Observation-level covariates cannot be used by distsamp()")
+    }
 })
 
 
 
 
-setMethod("summary", "unmarkedMultFrame",
-	function(object,...) {
-		cat("unmarkedFrame Object\n\n")
-		cat(nrow(object@y), "sites\n")
-		cat("Maximum number of observations per site:",obsNum(object),"\n")
-			mean.obs <- mean(rowSums(!is.na(getY(object))))
-		cat("Mean number of observations per site:",round(mean.obs,2),"\n")
-		cat("Number of primary survey periods:", object@numPrimary, "\n")
-		cat("Number of secondary survey periods:", 
-            obsNum(object) / object@numPrimary, "\n")
-        cat("Sites with at least one detection:", 
-			sum(apply(getY(object), 1, function(x) any(x > 0, na.rm=TRUE))), 
-				"\n\n")
-		cat("Tabulation of y observations:")
-		print(table(object@y, exclude=NULL))
-		if(!is.null(object@siteCovs)) {
-			cat("\nSite-level covariates:\n")
-			print(summary(object@siteCovs))
-			}
-		if(!is.null(object@obsCovs)) {
-			cat("\nObservation-level covariates:\n")
-			print(summary(object@obsCovs))
-			}
-		if(!is.null(object@yearlySiteCovs)) {
-			cat("\nYearly-site-level covariates:\n")
-			print(summary(object@yearlySiteCovs))
-			}
-	})
+setMethod("summary", "unmarkedMultFrame", function(object,...) {
+    cat("unmarkedFrame Object\n\n")
+    cat(nrow(object@y), "sites\n")
+    cat("Maximum number of observations per site:",ncol(object@y),"\n")
+    mean.obs <- mean(rowSums(!is.na(getY(object))))
+    cat("Mean number of observations per site:",round(mean.obs,2),"\n")
+    cat("Number of primary survey periods:", object@numPrimary, "\n")
+    cat("Number of secondary survey periods:",
+        obsNum(object) / object@numPrimary, "\n")
+    cat("Sites with at least one detection:",
+        sum(apply(getY(object), 1, function(x) any(x > 0, na.rm=TRUE))),
+        "\n\n")
+    cat("Tabulation of y observations:")
+    print(table(object@y, exclude=NULL))
+    if(!is.null(object@siteCovs)) {
+        cat("\nSite-level covariates:\n")
+        print(summary(object@siteCovs))
+    }
+    if(!is.null(object@obsCovs)) {
+        cat("\nObservation-level covariates:\n")
+        print(summary(object@obsCovs))
+    }
+    if(!is.null(object@yearlySiteCovs)) {
+        cat("\nYearly-site-level covariates:\n")
+        print(summary(object@yearlySiteCovs))
+    }
+})
 
 
 
 
-################################# PLOT METHODS #################################
-# TODO:  come up with nice show/summary/plot methods for each of these data types.
+################################# PLOT METHODS ###########################
+# TODO:  come up with nice show/summary/plot methods for each data types.
 
 setMethod("plot", c(x="unmarkedFrame", y="missing"),
-	function (x, y, panels = 1, colorkey, strip=FALSE, 
+	function (x, y, panels = 1, colorkey, strip=FALSE,
     ylab="Site", xlab="Observation", ...)
 {
     y <- getY(x)
@@ -567,10 +621,10 @@ setMethod("plot", c(x="unmarkedFrame", y="missing"),
     y2 <- melt(y, #measure.var = c("V1", "V2", "V3"),
         id.var=c("site","group"))
     if(missing(colorkey))
-        colorkey <- list(at=0:(ym+1), labels=list(labels=as.character(0:ym), 
-            at=(0:ym)+0.5))    
+        colorkey <- list(at=0:(ym+1), labels=list(labels=as.character(0:ym),
+            at=(0:ym)+0.5))
     levelplot(value ~ variable*site | group, y2,
-        scales=list(relation="free", x=list(labels=1:J)), 
+        scales=list(relation="free", x=list(labels=1:J)),
         colorkey=colorkey, strip=strip, xlab=xlab, ylab=ylab, ...)
 })
 
@@ -587,61 +641,16 @@ setMethod("hist", "unmarkedFrameDS", function(x, ...)
 
 
 
-#setMethod("plot", c(x="unmarkedFrameOccu", y="missing"),
-#		function(x) {
-#			if(is.null(x@mapInfo)) stop("mapInfo is required to plot an unmarkedFrameOccu object.")
-#			y <- getY(x)
-#			## get sites w/ at least one pos
-#			y <- as.factor(rowSums(y, na.rm = TRUE) > 0)
-#			levels(y) <- c("non-detection", "detection")
-#			siteCovs <- siteCovs(x)
-#			coords <- coordinates(x)
-#			if(is.null(x@mapInfo@projection)) {
-#				proj <- list(x = coords[,1], y = coords[,2])	
-#			} else {
-#				proj <- mapproject(x = coords[,1], y = coords[,2], projection = x@mapInfo@projection,
-#						parameters = x@mapInfo@parameters, orientation = x@mapInfo@orientation)
-#			}
-#			p <- qplot(x = proj$x, y = proj$y, colour = y, xlab = "longitude", ylab = "latitude")
-#			if(!is.null(x@mapInfo@projection)) {
-#				p + coord_map(project = x@mapInfo@projection)
-#			} else {
-#				p
-#			}
-#		})
-#
-
-#setMethod("plot", c(x="unmarkedFramePCount", y="missing"),
-#		function(x) {
-#			if(is.null(x@mapInfo)) stop("mapInfo is required to plot an unmarkedFramePCount object.")
-#			y <- getY(x)
-#			## plot maximums
-#			y <- apply(y, 1, max, na.rm = TRUE)
-#			siteCovs <- siteCovs(x)
-#			coords <- coordinates(x)
-#			if(is.null(x@mapInfo@projection)) {
-#				proj <- list(x = coords[,1], y = coords[,2])	
-#			} else {
-#				proj <- mapproject(x = coords[,1], y = coords[,2], projection = x@mapInfo@projection,
-#					parameters = x@mapInfo@parameters, orientation = x@mapInfo@orientation)
-#			}
-#			p <- qplot(x = proj$x, y = proj$y, colour = y, xlab = "longitude", ylab = "latitude")
-#			if(!is.null(x@mapInfo@projection)) {
-#				p + coord_map(project = x@mapInfo@projection)
-#			} else {
-#				p
-#			}
-#		})
-################################# SELECTORS ####################################
+################################# SELECTORS ##############################
 
 # i is the vector of sites to extract
 
 setMethod("[", c("unmarkedFrame", "numeric", "missing", "missing"),
-    function(x, i) 
-{  
+    function(x, i)
+{
     M <- numSites(x)
     if(length(i) == 0) return(x)
-    if(any(i < 0) && any(i > 0)) 
+    if(any(i < 0) && any(i > 0))
         stop("i must be all positive or all negative indices.")
     if(all(i < 0)) { # if i is negative, then convert to positive
         i <- (1:M)[i]
@@ -673,8 +682,8 @@ setMethod("[", c("unmarkedFrame", "numeric", "missing", "missing"),
 
 ## remove obs only
 setMethod("[", c("unmarkedFrame", "missing", "numeric", "missing"),
-		function(x, i, j) 
-{  
+		function(x, i, j)
+{
     y <- getY(x)
     obsCovs <- obsCovs(x)
     obsToY <- obsToY(x)
@@ -692,8 +701,8 @@ setMethod("[", c("unmarkedFrame", "missing", "numeric", "missing"),
 
 # i is as before and j is the obsNum to remove and corresponding y's
 setMethod("[", c("unmarkedFrame","numeric", "numeric", "missing"),
-		function(x, i, j) 
-{  
+		function(x, i, j)
+{
     ## first remove sites
     umf <- x[i,]
     umf <- umf[,j]
@@ -705,12 +714,12 @@ setMethod("[", c("unmarkedFrame","numeric", "numeric", "missing"),
 ### list is a ragged array of indices (y's) to include for each site.
 ### Typically useful for multilevel boostrapping.
 setMethod("[", c("unmarkedFrame","list", "missing", "missing"),
-    function(x, i) 
-{  
+    function(x, i)
+{
     m <- numSites(x)
     J <- R <- obsNum(x)
     o2y <- obsToY(x)
-    if (!identical(o2y, diag(R))) 
+    if (!identical(o2y, diag(R)))
         stop("Ragged subsetting of unmarkedFrames is only valid for diagonal obsToY.")
     J <- ncol(o2y)
     if (m != length(i)) stop("list length must be same as number of sites.")
@@ -721,7 +730,7 @@ setMethod("[", c("unmarkedFrame","list", "missing", "missing"),
     obsCovs <- ddply(obsCovs, ~.site, function(df) {
         site <- df$.site[1]
         obs <- i[[site]]
-        if (length(obs) > R) 
+        if (length(obs) > R)
             stop("All elements of list must be less than or equal to R.")
         obs <- c(obs, rep(NA, R-length(obs)))
         df[obs,]
@@ -746,8 +755,8 @@ setMethod("[", c("unmarkedFrame","list", "missing", "missing"),
 
 ## for multframes, must remove years at a time
 setMethod("[", c("unmarkedMultFrame", "missing", "numeric", "missing"),
-		function(x, i, j) 
-{  
+		function(x, i, j)
+{
     J <- obsNum(x)/x@numPrimary
     obs <- rep(1:x@numPrimary, each = J)
     years <- 1:x@numPrimary
@@ -767,10 +776,35 @@ setMethod("[", c("unmarkedMultFrame", "missing", "numeric", "missing"),
 
 ## for multframes, must remove years at a time
 setMethod("[", c("unmarkedMultFrame", "numeric", "missing", "missing"),
-		function(x, i, j) 
-{  
-    u <- callNextMethod(x, i, j)
-    ysc <- u@yearlySiteCovs
+		function(x, i, j)
+{
+    M <- numSites(x)
+    if(length(i) == 0) return(x)
+    if(any(i < 0) && any(i > 0))
+        stop("i must be all positive or all negative indices.")
+    if(all(i < 0)) { # if i is negative, then convert to positive
+        i <- (1:M)[i]
+        }
+    oldy <- getY(x)
+    y <- oldy[i,]
+    siteCovs <- siteCovs(x)
+    obsCovs <- obsCovs(x)
+    if (!is.null(siteCovs)) {
+        siteCovs <- siteCovs(x)[i, , drop = FALSE]
+        }
+    if (!is.null(obsCovs)) {
+        R <- obsNum(x)
+        obsCovs <- cbind(.site=rep(1:M, each = R), obsCovs(x))
+        obsCovs <- ldply(i, function(site) {
+            subset(obsCovs, .site == site)
+            })
+        obsCovs$.site <- NULL
+        }
+    u <- unmarkedMultFrame(y=matrix(y, ncol=ncol(oldy)),
+                           siteCovs=siteCovs,
+                           obsCovs=obsCovs,
+                           numPrimary=x@numPrimary)
+    ysc <- x@yearlySiteCovs
     if(!is.null(ysc)) {
         sites <- 1:nrow(ysc)
         T <- x@numPrimary
@@ -778,7 +812,8 @@ setMethod("[", c("unmarkedMultFrame", "numeric", "missing", "missing"),
         ysc <- ysc[rep(keep, each=T),, drop=FALSE]
         u@yearlySiteCovs <- ysc
         }
-    return(u)
+    u
+
 })
 
 
@@ -788,10 +823,10 @@ setMethod("head", "unmarkedFrame",
 			umf <- x[1:n,]
 			umf
 		})
-		
-############################### COERCION #######################################
 
-setAs("data.frame", "unmarkedFrame", function(from) 
+############################### COERCION #################################
+
+setAs("data.frame", "unmarkedFrame", function(from)
 {
     umf <- formatWide(from)
     umf
@@ -799,7 +834,7 @@ setAs("data.frame", "unmarkedFrame", function(from)
 
 
 
-setAs("unmarkedFrame", "data.frame", function(from) 
+setAs("unmarkedFrame", "data.frame", function(from)
 {
     obsCovs <- obsCovs(from)
     siteCovs <- siteCovs(from)
@@ -814,15 +849,15 @@ setAs("unmarkedFrame", "data.frame", function(from)
     if(is.null(obsCovs)) {
         obsCovs <- matrix(0,nrow(y),0)
     } else {
-        obsCovs <- data.frame(lapply(obsCovs, 
+        obsCovs <- data.frame(lapply(obsCovs,
             function(x) matrix(x, nrow(y), obsNum,byrow=T)))
         }
     df <- data.frame(y, siteCovs, obsCovs)
     df
 })
-		
-		
-		
 
-			
-		
+
+
+
+
+
